
#import "igViewController.h"

@implementation igDataRecord
@synthesize date, name, sales;
@end

@implementation igViewController
{
    IGChartView *infraChart;
    IGLineSeries *chartSeries;
    NSMutableArray *data;
    IGCategorySeriesDataSourceHelper *source;
}

- (void)viewDidLoad
{
    [super viewDidLoad];

    data = [[NSMutableArray alloc] init];
    [self populateData];

    infraChart = [[IGChartView alloc] init];
    infraChart.frame = self.view.frame;
    infraChart.autoresizingMask = UIViewAutoresizingFlexibleHeight|UIViewAutoresizingFlexibleWidth;
    infraChart.delegate = self;

    source = [[IGCategorySeriesDataSourceHelper alloc] initWithData:data andValuePath:@"sales"];
    source.labelPath = @"name";
    chartSeries = (IGLineSeries *)[infraChart addSeriesForType:[IGLineSeries class] usingKey:@"chartSeries" withDataSource:source firstAxisKey:@"xAxis" secondAxisKey:@"yAxis"];

    [self.view addSubview:infraChart];
}

-(void)populateData
{
    /*
        Response string from JSON looks like below:

        {
            "records" : [
                {
                    "date" : "25/5/2012",
                    "name" : "Jane Doe",
                    "sales" : 102995
                },
                {
                    "date" : "10/10/2012",
                    "name" : "John Doe",
                    "sales" : 120019
                },
                {
                    "date" : "4/2/2012",
                    "name" : "Jill Doe",
                    "sales" : 95344
                }
            ]
        }
     */

    NSString *jsonResponseString = @"{ \"records\" : [{ \"date\" : \"25/5/2012\", \"name\" : \"Jane Doe\", \"sales\" : 102995 }, { \"date\" : \"10/10/2012\", \"name\" : \"John Doe\", \"sales\" : 120019 }, { \"date\" : \"4/2/2012\", \"name\" : \"Jill Doe\", \"sales\" : 95344 }] }";
    NSData *jsonResponse = [jsonResponseString dataUsingEncoding:NSUTF8StringEncoding];
    NSDictionary *jsonData = [NSJSONSerialization JSONObjectWithData:jsonResponse options:NSJSONReadingMutableLeaves error:nil];

    NSArray *dataRecordsArray = [jsonData objectForKey:@"records"];
    for (NSDictionary *dataRecord in dataRecordsArray)
    {
        igDataRecord *record = [[igDataRecord alloc] init];
        record.date = [dataRecord objectForKey:@"date"];
        record.name = [dataRecord objectForKey:@"name"];
        record.sales = [[dataRecord objectForKey:@"sales"] doubleValue];
        [data addObject:record];
    }
}

-(NSString *)chartView:(IGChartView *)chartView labelForAxis:(IGAxis *)axis withItem:(NSObject *)item
{
    if (axis == chartSeries.xAxis)
        return ((IGCategoryPoint *)item).label;

    // y-axis label
    return [NSString stringWithFormat:@"🇺🇸- %.2f", ((NSNumber *)item).doubleValue];
}

@end